@@ -1,5 +1,5 @@
 # Load example symDMatrix (G)
-load.symDMatrix(system.file("extdata", "G.RData", package = "symDMatrix"))
+load.symDMatrix(system.file("extdata", "G.RData", package = "symDMatrix"), readonly = TRUE)
 
 # Get the block size
 blockSize(G)
